package com.ruoyi.ss.articleClassify.service;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.SmArticleClassify;
import com.ruoyi.ss.articleClassify.domain.SmArticleClassifyQuery;

import java.util.List;

/**
 * 分类管理 服务层
 *
 * @author ruoyi
 */
public interface ISmArticleClassifyService
{
    /**
     * 查询分类管理数据
     *
     * @param dto 查询条件
     * @return 分类信息集合
     */
    public List<SmArticleClassify> selectClassifyList(SmArticleClassifyQuery dto);

    /**
     * 查询分类树结构信息
     *
     * @param asArticleClassify 分类信息
     * @return 分类树信息集合
     */
    public List<TreeSelect> selectClassifyTreeList(SmArticleClassifyQuery asArticleClassify);

    /**
     * 构建前端所需要树结构
     *
     * @param asArticleClassifys 分类列表
     * @return 树结构列表
     */
    public List<SmArticleClassify> buildClassifyTree(List<SmArticleClassify> asArticleClassifys);

    /**
     * 构建前端所需要下拉树结构
     *
     * @param asArticleClassifys 分类列表
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildClassifyTreeSelect(List<SmArticleClassify> asArticleClassifys);

//    /**
//     * 根据角色ID查询分类树信息
//     *
//     * @param roleId 角色ID
//     * @return 选中分类列表
//     */
//    public List<Long> selectClassifyListByRoleId(Long roleId);

    /**
     * 根据分类ID查询信息
     *
     * @param classifyId 分类ID
     * @return 分类信息
     */
    public SmArticleClassify selectClassifyById(Long classifyId);

    /**
     * 根据ID查询所有子分类（正常状态）
     *
     * @param classifyId 分类ID
     * @return 子分类数
     */
    public int selectNormalChildrenClassifyById(Long classifyId);

    /**
     * 是否存在分类子节点
     *
     * @param classifyId 分类ID
     * @return 结果
     */
    public boolean hasChildByclassifyId(Long classifyId);

    /**
     * 查询分类是否存在用户
     *
     * @param classifyId 分类ID
     * @return 结果 true 存在 false 不存在
     */
    public boolean checkClassifyExistArticle(Long classifyId);

    /**
     * 校验分类名称是否唯一
     *
     * @param asArticleClassify 分类信息
     * @return 结果
     */
    public boolean checkClassifyNameUnique(SmArticleClassify asArticleClassify);

    /**
     * 校验分类是否有数据权限
     *
     * @param classifyId 分类id
     */
    public void checkClassifyDataScope(Long classifyId);

    /**
     * 新增保存分类信息
     *
     * @param asArticleClassify 分类信息
     * @return 结果
     */
    public int insertClassify(SmArticleClassify asArticleClassify);

    /**
     * 修改保存分类信息
     *
     * @param asArticleClassify 分类信息
     * @return 结果
     */
    public int updateClassify(SmArticleClassify asArticleClassify);

    /**
     * 删除分类管理信息
     *
     * @param classifyId 分类ID
     * @return 结果
     */
    public int deleteClassifyById(Long classifyId);

    /**
     * 是否系统内置
     * @param classifyId
     * @return
     */
    boolean checkIsBuiltSystem(Long classifyId);
}
